@@ -9,7 +9,7 @@ from sql_models.shared.visibility.RoleVisibility import RoleVisibility
 class ManufacturerEntity(RoleVisibility, SQLCamelModel, table=True):
     __tablename__ = 'manufacturer'
 
-    id: int = Field(
+    id: int | None = Field(
         primary_key=True,
         sa_column=Column(
             Integer,
@@ -18,6 +18,8 @@ class ManufacturerEntity(RoleVisibility, SQLCamelModel, table=True):
         ),
     )
 
+    name: str = Field()
+
     image_width: int | None
     image_height: int | None
 
