@@ -9,7 +9,7 @@ from sql_models.motorcycle_model.MotorcycleModel import MotorcycleModel
 
 
 class MotorcycleModelEntity(RoleVisibility, SQLCamelModel, table=True):
-    __tablename__ = 'models'
+    __tablename__ = 'model'
 
     id: int = Field(
         primary_key=True,
